@@ -1025,9 +1025,10 @@ class VariableClUpdateProfileRepoName(ReadonlyVariable):
     def get(self):
         rep_set = self.Get(self.storage)
         url = self.Get(self.url)
-        rep = rep_set.get_repository(url, branch=None)
-        if rep:
-            return rep.repo_name
+        if url:
+            rep = rep_set.get_repository(url, branch=None)
+            if rep:
+                return rep.repo_name
         return ""
 
 
